# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import accounts_pb2 as accounts_dot_grpc_dot_accounts__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class AssetControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/darsman.accounts.AssetController/Create',
                request_serializer=accounts_dot_grpc_dot_accounts__pb2.AssetCreateRequest.SerializeToString,
                response_deserializer=accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
                )
        self.List = channel.unary_unary(
                '/darsman.accounts.AssetController/List',
                request_serializer=accounts_dot_grpc_dot_accounts__pb2.ListAssetRequest.SerializeToString,
                response_deserializer=accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
                )


class AssetControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AssetControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=accounts_dot_grpc_dot_accounts__pb2.AssetCreateRequest.FromString,
                    response_serializer=accounts_dot_grpc_dot_accounts__pb2.Response.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=accounts_dot_grpc_dot_accounts__pb2.ListAssetRequest.FromString,
                    response_serializer=accounts_dot_grpc_dot_accounts__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'darsman.accounts.AssetController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AssetController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/darsman.accounts.AssetController/Create',
            accounts_dot_grpc_dot_accounts__pb2.AssetCreateRequest.SerializeToString,
            accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/darsman.accounts.AssetController/List',
            accounts_dot_grpc_dot_accounts__pb2.ListAssetRequest.SerializeToString,
            accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class UserControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.BulkRetrieve = channel.unary_unary(
                '/darsman.accounts.UserController/BulkRetrieve',
                request_serializer=accounts_dot_grpc_dot_accounts__pb2.UserBulkRetrieveRequest.SerializeToString,
                response_deserializer=accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
                )
        self.Retrieve = channel.unary_unary(
                '/darsman.accounts.UserController/Retrieve',
                request_serializer=accounts_dot_grpc_dot_accounts__pb2.UserRetrieveRequest.SerializeToString,
                response_deserializer=accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
                )
        self.Update = channel.unary_unary(
                '/darsman.accounts.UserController/Update',
                request_serializer=accounts_dot_grpc_dot_accounts__pb2.UserUpdateRequest.SerializeToString,
                response_deserializer=accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
                )


class UserControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def BulkRetrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'BulkRetrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.BulkRetrieve,
                    request_deserializer=accounts_dot_grpc_dot_accounts__pb2.UserBulkRetrieveRequest.FromString,
                    response_serializer=accounts_dot_grpc_dot_accounts__pb2.Response.SerializeToString,
            ),
            'Retrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.Retrieve,
                    request_deserializer=accounts_dot_grpc_dot_accounts__pb2.UserRetrieveRequest.FromString,
                    response_serializer=accounts_dot_grpc_dot_accounts__pb2.Response.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=accounts_dot_grpc_dot_accounts__pb2.UserUpdateRequest.FromString,
                    response_serializer=accounts_dot_grpc_dot_accounts__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'darsman.accounts.UserController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def BulkRetrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/darsman.accounts.UserController/BulkRetrieve',
            accounts_dot_grpc_dot_accounts__pb2.UserBulkRetrieveRequest.SerializeToString,
            accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Retrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/darsman.accounts.UserController/Retrieve',
            accounts_dot_grpc_dot_accounts__pb2.UserRetrieveRequest.SerializeToString,
            accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/darsman.accounts.UserController/Update',
            accounts_dot_grpc_dot_accounts__pb2.UserUpdateRequest.SerializeToString,
            accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class WalletControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListPackages = channel.unary_unary(
                '/darsman.accounts.WalletController/ListPackages',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
                )
        self.Retrieve = channel.unary_unary(
                '/darsman.accounts.WalletController/Retrieve',
                request_serializer=accounts_dot_grpc_dot_accounts__pb2.WalletRetrieveRequest.SerializeToString,
                response_deserializer=accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
                )
        self.RetrievePackage = channel.unary_unary(
                '/darsman.accounts.WalletController/RetrievePackage',
                request_serializer=accounts_dot_grpc_dot_accounts__pb2.WalletPackageRetrieveRequest.SerializeToString,
                response_deserializer=accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
                )
        self.Spend = channel.unary_unary(
                '/darsman.accounts.WalletController/Spend',
                request_serializer=accounts_dot_grpc_dot_accounts__pb2.WalletSpendRequest.SerializeToString,
                response_deserializer=accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
                )
        self.Topup = channel.unary_unary(
                '/darsman.accounts.WalletController/Topup',
                request_serializer=accounts_dot_grpc_dot_accounts__pb2.WalletTopupRequest.SerializeToString,
                response_deserializer=accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
                )


class WalletControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListPackages(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RetrievePackage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Spend(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Topup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WalletControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListPackages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPackages,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=accounts_dot_grpc_dot_accounts__pb2.Response.SerializeToString,
            ),
            'Retrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.Retrieve,
                    request_deserializer=accounts_dot_grpc_dot_accounts__pb2.WalletRetrieveRequest.FromString,
                    response_serializer=accounts_dot_grpc_dot_accounts__pb2.Response.SerializeToString,
            ),
            'RetrievePackage': grpc.unary_unary_rpc_method_handler(
                    servicer.RetrievePackage,
                    request_deserializer=accounts_dot_grpc_dot_accounts__pb2.WalletPackageRetrieveRequest.FromString,
                    response_serializer=accounts_dot_grpc_dot_accounts__pb2.Response.SerializeToString,
            ),
            'Spend': grpc.unary_unary_rpc_method_handler(
                    servicer.Spend,
                    request_deserializer=accounts_dot_grpc_dot_accounts__pb2.WalletSpendRequest.FromString,
                    response_serializer=accounts_dot_grpc_dot_accounts__pb2.Response.SerializeToString,
            ),
            'Topup': grpc.unary_unary_rpc_method_handler(
                    servicer.Topup,
                    request_deserializer=accounts_dot_grpc_dot_accounts__pb2.WalletTopupRequest.FromString,
                    response_serializer=accounts_dot_grpc_dot_accounts__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'darsman.accounts.WalletController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class WalletController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListPackages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/darsman.accounts.WalletController/ListPackages',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Retrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/darsman.accounts.WalletController/Retrieve',
            accounts_dot_grpc_dot_accounts__pb2.WalletRetrieveRequest.SerializeToString,
            accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RetrievePackage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/darsman.accounts.WalletController/RetrievePackage',
            accounts_dot_grpc_dot_accounts__pb2.WalletPackageRetrieveRequest.SerializeToString,
            accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Spend(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/darsman.accounts.WalletController/Spend',
            accounts_dot_grpc_dot_accounts__pb2.WalletSpendRequest.SerializeToString,
            accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Topup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/darsman.accounts.WalletController/Topup',
            accounts_dot_grpc_dot_accounts__pb2.WalletTopupRequest.SerializeToString,
            accounts_dot_grpc_dot_accounts__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
