# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: accounts/grpc/accounts.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61\x63\x63ounts/grpc/accounts.proto\x12\x10\x64\x61rsman.accounts\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xeb\x02\n\x12\x41ssetCreateRequest\x12\x10\n\x08owner_id\x18\x01 \x01(\t\x12\x10\n\x08\x61sset_id\x18\x02 \x01(\t\x12\x16\n\tis_active\x18\x03 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0b\x65xpire_date\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x12\n\nasset_name\x18\x06 \x01(\t\x12\x30\n\nextra_data\x18\x07 \x01(\x0b\x32\x17.google.protobuf.StructH\x02\x88\x01\x01\x12#\n\x16installment_identifier\x18\x08 \x01(\tH\x03\x88\x01\x01\x12#\n\x16registration_completed\x18\t \x01(\x08H\x04\x88\x01\x01\x42\x0c\n\n_is_activeB\x0e\n\x0c_expire_dateB\r\n\x0b_extra_dataB\x19\n\x17_installment_identifierB\x19\n\x17_registration_completed\"\xf6\x01\n\x1c\x45\x64ucationalExperienceRequest\x12\x1d\n\x10previous_courses\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x02 \x01(\tH\x01\x88\x01\x01\x12 \n\x13learning_challenges\x18\x03 \x01(\tH\x02\x88\x01\x01\x12&\n\x19\x63ourse_selection_criteria\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x13\n\x11_previous_coursesB\x0b\n\t_feedbackB\x16\n\x14_learning_challengesB\x1c\n\x1a_course_selection_criteria\"\xf7\x01\n\x1d\x45\x64ucationalExperienceResponse\x12\x1d\n\x10previous_courses\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x02 \x01(\tH\x01\x88\x01\x01\x12 \n\x13learning_challenges\x18\x03 \x01(\tH\x02\x88\x01\x01\x12&\n\x19\x63ourse_selection_criteria\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x13\n\x11_previous_coursesB\x0b\n\t_feedbackB\x16\n\x14_learning_challengesB\x1c\n\x1a_course_selection_criteria\"\xc5\x02\n\x0bGoalRequest\x12$\n\x17\x63ourse_discovery_method\x18\x01 \x01(\tH\x00\x88\x01\x01\x12&\n\x19\x63ourse_participation_goal\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1e\n\x11\x64\x61ily_study_hours\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1d\n\x10preferred_device\x18\x04 \x01(\tH\x03\x88\x01\x01\x12&\n\x19preferred_learning_format\x18\x05 \x01(\tH\x04\x88\x01\x01\x42\x1a\n\x18_course_discovery_methodB\x1c\n\x1a_course_participation_goalB\x14\n\x12_daily_study_hoursB\x13\n\x11_preferred_deviceB\x1c\n\x1a_preferred_learning_format\"\xc6\x02\n\x0cGoalResponse\x12$\n\x17\x63ourse_discovery_method\x18\x01 \x01(\tH\x00\x88\x01\x01\x12&\n\x19\x63ourse_participation_goal\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1e\n\x11\x64\x61ily_study_hours\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1d\n\x10preferred_device\x18\x04 \x01(\tH\x03\x88\x01\x01\x12&\n\x19preferred_learning_format\x18\x05 \x01(\tH\x04\x88\x01\x01\x42\x1a\n\x18_course_discovery_methodB\x1c\n\x1a_course_participation_goalB\x14\n\x12_daily_study_hoursB\x13\n\x11_preferred_deviceB\x1c\n\x1a_preferred_learning_format\"$\n\x10ListAssetRequest\x12\x10\n\x08owner_id\x18\x01 \x01(\t\"\xe0\x04\n\x0eProfileRequest\x12\x10\n\x03job\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\"\n\x15last_education_degree\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05major\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x18\n\x0b\x66\x61ther_name\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x1a\n\rfirst_name_en\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x19\n\x0clast_name_en\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x1b\n\x0emarital_status\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x13\n\x06gender\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x14\n\x07mobile2\x18\t \x01(\tH\x08\x88\x01\x01\x12\x15\n\x08landline\x18\n \x01(\tH\t\x88\x01\x01\x12\x13\n\x06\x65mail2\x18\x0b \x01(\tH\n\x88\x01\x01\x12\x14\n\x07\x63ountry\x18\x0c \x01(\tH\x0b\x88\x01\x01\x12\x15\n\x08province\x18\r \x01(\tH\x0c\x88\x01\x01\x12\x11\n\x04\x63ity\x18\x0e \x01(\tH\r\x88\x01\x01\x12\"\n\x15programming_interests\x18\x0f \x01(\tH\x0e\x88\x01\x01\x42\x06\n\x04_jobB\x18\n\x16_last_education_degreeB\x08\n\x06_majorB\x0e\n\x0c_father_nameB\x10\n\x0e_first_name_enB\x0f\n\r_last_name_enB\x11\n\x0f_marital_statusB\t\n\x07_genderB\n\n\x08_mobile2B\x0b\n\t_landlineB\t\n\x07_email2B\n\n\x08_countryB\x0b\n\t_provinceB\x07\n\x05_cityB\x18\n\x16_programming_interests\"\xe1\x04\n\x0fProfileResponse\x12\x10\n\x03job\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\"\n\x15last_education_degree\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05major\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x18\n\x0b\x66\x61ther_name\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x1a\n\rfirst_name_en\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x19\n\x0clast_name_en\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x1b\n\x0emarital_status\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x13\n\x06gender\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x14\n\x07mobile2\x18\t \x01(\tH\x08\x88\x01\x01\x12\x15\n\x08landline\x18\n \x01(\tH\t\x88\x01\x01\x12\x13\n\x06\x65mail2\x18\x0b \x01(\tH\n\x88\x01\x01\x12\x14\n\x07\x63ountry\x18\x0c \x01(\tH\x0b\x88\x01\x01\x12\x15\n\x08province\x18\r \x01(\tH\x0c\x88\x01\x01\x12\x11\n\x04\x63ity\x18\x0e \x01(\tH\r\x88\x01\x01\x12\"\n\x15programming_interests\x18\x0f \x01(\tH\x0e\x88\x01\x01\x42\x06\n\x04_jobB\x18\n\x16_last_education_degreeB\x08\n\x06_majorB\x0e\n\x0c_father_nameB\x10\n\x0e_first_name_enB\x0f\n\r_last_name_enB\x11\n\x0f_marital_statusB\t\n\x07_genderB\n\n\x08_mobile2B\x0b\n\t_landlineB\t\n\x07_email2B\n\n\x08_countryB\x0b\n\t_provinceB\x07\n\x05_cityB\x18\n\x16_programming_interests\"o\n\x08Response\x12\x11\n\x04\x63ode\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07message\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\x07\n\x05_codeB\n\n\x08_message\"\x80\x01\n\x0cSkillRequest\x12\x1c\n\x0fproblem_solving\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12#\n\x16technology_familiarity\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x12\n\x10_problem_solvingB\x19\n\x17_technology_familiarity\"\x81\x01\n\rSkillResponse\x12\x1c\n\x0fproblem_solving\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12#\n\x16technology_familiarity\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x12\n\x10_problem_solvingB\x19\n\x17_technology_familiarity\"\xc0\x01\n\x12SocialMediaRequest\x12 \n\x13\x61\x63tive_social_media\x18\x01 \x01(\tH\x00\x88\x01\x01\x12$\n\x17notification_preference\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x0eonline_profile\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x16\n\x14_active_social_mediaB\x1a\n\x18_notification_preferenceB\x11\n\x0f_online_profile\"\xc1\x01\n\x13SocialMediaResponse\x12 \n\x13\x61\x63tive_social_media\x18\x01 \x01(\tH\x00\x88\x01\x01\x12$\n\x17notification_preference\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x0eonline_profile\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x16\n\x14_active_social_mediaB\x1a\n\x18_notification_preferenceB\x11\n\x0f_online_profile\"\xbd\x01\n\x11SuggestionRequest\x12\x1f\n\x12questions_or_notes\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cvip_interest\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12&\n\x19\x66uture_course_suggestions\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x15\n\x13_questions_or_notesB\x0f\n\r_vip_interestB\x1c\n\x1a_future_course_suggestions\"\xbe\x01\n\x12SuggestionResponse\x12\x1f\n\x12questions_or_notes\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cvip_interest\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12&\n\x19\x66uture_course_suggestions\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x15\n\x13_questions_or_notesB\x0f\n\r_vip_interestB\x1c\n\x1a_future_course_suggestions\"*\n\x17UserBulkRetrieveRequest\x12\x0f\n\x07uuid_id\x18\x01 \x03(\t\"&\n\x13UserRetrieveRequest\x12\x0f\n\x07uuid_id\x18\x01 \x01(\t\"\xe4\x06\n\x11UserUpdateRequest\x12\x12\n\x05\x65mail\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07\x61\x64\x64ress\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\rdate_of_birth\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x12\n\x05\x61\x62out\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x1a\n\rnational_code\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x16\n\tlast_name\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x17\n\nfirst_name\x18\x08 \x01(\tH\x06\x88\x01\x01\x12\x36\n\x07profile\x18\t \x01(\x0b\x32 .darsman.accounts.ProfileRequestH\x07\x88\x01\x01\x12\x14\n\x07uuid_id\x18\n \x01(\tH\x08\x88\x01\x01\x12\x32\n\x05skill\x18\x0b \x01(\x0b\x32\x1e.darsman.accounts.SkillRequestH\t\x88\x01\x01\x12\x45\n\x0fwork_experience\x18\x0c \x01(\x0b\x32\'.darsman.accounts.WorkExperienceRequestH\n\x88\x01\x01\x12\x30\n\x04goal\x18\r \x01(\x0b\x32\x1d.darsman.accounts.GoalRequestH\x0b\x88\x01\x01\x12S\n\x16\x65\x64ucational_experience\x18\x0e \x01(\x0b\x32..darsman.accounts.EducationalExperienceRequestH\x0c\x88\x01\x01\x12?\n\x0csocial_media\x18\x0f \x01(\x0b\x32$.darsman.accounts.SocialMediaRequestH\r\x88\x01\x01\x12<\n\nsuggestion\x18\x10 \x01(\x0b\x32#.darsman.accounts.SuggestionRequestH\x0e\x88\x01\x01\x42\x08\n\x06_emailB\n\n\x08_addressB\x10\n\x0e_date_of_birthB\x08\n\x06_aboutB\x10\n\x0e_national_codeB\x0c\n\n_last_nameB\r\n\x0b_first_nameB\n\n\x08_profileB\n\n\x08_uuid_idB\x08\n\x06_skillB\x12\n\x10_work_experienceB\x07\n\x05_goalB\x19\n\x17_educational_experienceB\x0f\n\r_social_mediaB\r\n\x0b_suggestion\",\n\x1cWalletPackageRetrieveRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\")\n\x15WalletRetrieveRequest\x12\x10\n\x08owner_id\x18\x01 \x01(\t\"5\n\x12WalletSpendRequest\x12\x0f\n\x07uuid_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x05\"q\n\x12WalletTopupRequest\x12\x13\n\x06\x61mount\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x19\n\x0cpackage_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0f\n\x07uuid_id\x18\x03 \x01(\tB\t\n\x07_amountB\x0f\n\r_package_name\"\xe3\x01\n\x15WorkExperienceRequest\x12\"\n\x15programming_languages\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11programming_tools\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07summary\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1e\n\x11programming_level\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x18\n\x16_programming_languagesB\x14\n\x12_programming_toolsB\n\n\x08_summaryB\x14\n\x12_programming_level\"\xe4\x01\n\x16WorkExperienceResponse\x12\"\n\x15programming_languages\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11programming_tools\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07summary\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1e\n\x11programming_level\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x18\n\x16_programming_languagesB\x14\n\x12_programming_toolsB\n\n\x08_summaryB\x14\n\x12_programming_level2\xa9\x01\n\x0f\x41ssetController\x12L\n\x06\x43reate\x12$.darsman.accounts.AssetCreateRequest\x1a\x1a.darsman.accounts.Response\"\x00\x12H\n\x04List\x12\".darsman.accounts.ListAssetRequest\x1a\x1a.darsman.accounts.Response\"\x00\x32\x87\x02\n\x0eUserController\x12W\n\x0c\x42ulkRetrieve\x12).darsman.accounts.UserBulkRetrieveRequest\x1a\x1a.darsman.accounts.Response\"\x00\x12O\n\x08Retrieve\x12%.darsman.accounts.UserRetrieveRequest\x1a\x1a.darsman.accounts.Response\"\x00\x12K\n\x06Update\x12#.darsman.accounts.UserUpdateRequest\x1a\x1a.darsman.accounts.Response\"\x00\x32\xa6\x03\n\x10WalletController\x12\x44\n\x0cListPackages\x12\x16.google.protobuf.Empty\x1a\x1a.darsman.accounts.Response\"\x00\x12Q\n\x08Retrieve\x12\'.darsman.accounts.WalletRetrieveRequest\x1a\x1a.darsman.accounts.Response\"\x00\x12_\n\x0fRetrievePackage\x12..darsman.accounts.WalletPackageRetrieveRequest\x1a\x1a.darsman.accounts.Response\"\x00\x12K\n\x05Spend\x12$.darsman.accounts.WalletSpendRequest\x1a\x1a.darsman.accounts.Response\"\x00\x12K\n\x05Topup\x12$.darsman.accounts.WalletTopupRequest\x1a\x1a.darsman.accounts.Response\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'accounts.grpc.accounts_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ASSETCREATEREQUEST']._serialized_start=110
  _globals['_ASSETCREATEREQUEST']._serialized_end=473
  _globals['_EDUCATIONALEXPERIENCEREQUEST']._serialized_start=476
  _globals['_EDUCATIONALEXPERIENCEREQUEST']._serialized_end=722
  _globals['_EDUCATIONALEXPERIENCERESPONSE']._serialized_start=725
  _globals['_EDUCATIONALEXPERIENCERESPONSE']._serialized_end=972
  _globals['_GOALREQUEST']._serialized_start=975
  _globals['_GOALREQUEST']._serialized_end=1300
  _globals['_GOALRESPONSE']._serialized_start=1303
  _globals['_GOALRESPONSE']._serialized_end=1629
  _globals['_LISTASSETREQUEST']._serialized_start=1631
  _globals['_LISTASSETREQUEST']._serialized_end=1667
  _globals['_PROFILEREQUEST']._serialized_start=1670
  _globals['_PROFILEREQUEST']._serialized_end=2278
  _globals['_PROFILERESPONSE']._serialized_start=2281
  _globals['_PROFILERESPONSE']._serialized_end=2890
  _globals['_RESPONSE']._serialized_start=2892
  _globals['_RESPONSE']._serialized_end=3003
  _globals['_SKILLREQUEST']._serialized_start=3006
  _globals['_SKILLREQUEST']._serialized_end=3134
  _globals['_SKILLRESPONSE']._serialized_start=3137
  _globals['_SKILLRESPONSE']._serialized_end=3266
  _globals['_SOCIALMEDIAREQUEST']._serialized_start=3269
  _globals['_SOCIALMEDIAREQUEST']._serialized_end=3461
  _globals['_SOCIALMEDIARESPONSE']._serialized_start=3464
  _globals['_SOCIALMEDIARESPONSE']._serialized_end=3657
  _globals['_SUGGESTIONREQUEST']._serialized_start=3660
  _globals['_SUGGESTIONREQUEST']._serialized_end=3849
  _globals['_SUGGESTIONRESPONSE']._serialized_start=3852
  _globals['_SUGGESTIONRESPONSE']._serialized_end=4042
  _globals['_USERBULKRETRIEVEREQUEST']._serialized_start=4044
  _globals['_USERBULKRETRIEVEREQUEST']._serialized_end=4086
  _globals['_USERRETRIEVEREQUEST']._serialized_start=4088
  _globals['_USERRETRIEVEREQUEST']._serialized_end=4126
  _globals['_USERUPDATEREQUEST']._serialized_start=4129
  _globals['_USERUPDATEREQUEST']._serialized_end=4997
  _globals['_WALLETPACKAGERETRIEVEREQUEST']._serialized_start=4999
  _globals['_WALLETPACKAGERETRIEVEREQUEST']._serialized_end=5043
  _globals['_WALLETRETRIEVEREQUEST']._serialized_start=5045
  _globals['_WALLETRETRIEVEREQUEST']._serialized_end=5086
  _globals['_WALLETSPENDREQUEST']._serialized_start=5088
  _globals['_WALLETSPENDREQUEST']._serialized_end=5141
  _globals['_WALLETTOPUPREQUEST']._serialized_start=5143
  _globals['_WALLETTOPUPREQUEST']._serialized_end=5256
  _globals['_WORKEXPERIENCEREQUEST']._serialized_start=5259
  _globals['_WORKEXPERIENCEREQUEST']._serialized_end=5486
  _globals['_WORKEXPERIENCERESPONSE']._serialized_start=5489
  _globals['_WORKEXPERIENCERESPONSE']._serialized_end=5717
  _globals['_ASSETCONTROLLER']._serialized_start=5720
  _globals['_ASSETCONTROLLER']._serialized_end=5889
  _globals['_USERCONTROLLER']._serialized_start=5892
  _globals['_USERCONTROLLER']._serialized_end=6155
  _globals['_WALLETCONTROLLER']._serialized_start=6158
  _globals['_WALLETCONTROLLER']._serialized_end=6580
# @@protoc_insertion_point(module_scope)
