from setuptools import setup

with open("README.md", "r") as f:
    long_description = f.read()


setup(
    name="admac",
    version="1.2.1",
    author="Ellnamin",
    author_email="ellnamin.business@gmail.com",
    description="Async Account Service for Darsman Academy",
    long_description=long_description,
    packages=["admac", "admac/grpc"],
    install_requires=[
        "annotated-types==0.6.0",
        "email-validator==2.1.1",
        "grpcio==1.62.1",
        "grpcio-tools==1.62.1",
        "protobuf==4.25.3",
        "pydantic==2.7.0",
        "pydantic-settings==2.10.1",
        "pydantic_core==2.18.1",
        "python-dotenv==1.1.1",
        "typing-inspection==0.4.1",
        "typing_extensions==4.14.1",
    ],
    setup_requires=["wheel", "setuptools"],
)
